# MIT License
# 
# Copyright (c) 2021~2022 [coder4869](https://github.com/coder4869)
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

set(ViConfigToolDir ${CMAKE_CURRENT_LIST_DIR})
set(BIN_NAME ViConfigTool)
set(INC_DEPS ${INC_FILES} ${INC_GROUP})
set(LIB_DEPS QLandscapeDB QtCoreKit CCoreKit )

FILE(GLOB_RECURSE ViConfigTool_SRC
    ${ViConfigToolDir}/*.h
    ${ViConfigToolDir}/*.hpp

    ${ViConfigToolDir}/*.c
    ${ViConfigToolDir}/*.cc
    ${ViConfigToolDir}/*.cpp
    )

# Special For Qt
if(WITH_QT)
    FILE(GLOB_RECURSE ViConfigTool_FORMs 
        ${ViConfigToolDir}/Forms/*.ui
        )

    FILE(GLOB_RECURSE ViConfigTool_RES
        ${ViConfigToolDir}/Res/*.qrc
        ${ViConfigToolDir}/Res/*.qml
        ${ViConfigToolDir}/Res/*.js
        )

    # gen src by forms
    # qt5_wrap_ui(ViConfigTool_RES_UIC ${ViConfigTool_FORMs})
    # set(ViConfigTool_SRC ${ViConfigTool_SRC} ${ViConfigTool_FORMs} ${ViConfigTool_RES} ${ViConfigTool_RES_UIC})

    set(ViConfigTool_SRC ${ViConfigTool_SRC} ${ViConfigTool_FORMs} ${ViConfigTool_RES})

    set(INC_DEPS ${INC_DEPS} ${INC_QT})
    set(LIB_DEPS ${LIB_DEPS} ${LIB_QT})
endif()

# Special For Python
if(WITH_PY)
    set(INC_DEPS ${INC_DEPS} ${INC_PY})
    set(LIB_DEPS ${LIB_DEPS} ${LIB_PY})
endif(WITH_PY)

# Gen Source Tree
if(NOT ANDROID)
    source_group(
        TREE ${ViConfigToolDir}
        PREFIX "ViConfigTool"
        FILES ${ViConfigTool_SRC}
        )
endif(NOT ANDROID)

if(WITH_QT)
    # gen src by forms
    qt5_wrap_ui(ViConfigTool_RES_UIC ${ViConfigTool_FORMs})
    set(ViConfigTool_SRC ${ViConfigTool_SRC} ${ViConfigTool_RES_UIC})
endif()


################################## build bin ##################################
INCLUDE_DIRECTORIES(${CMAKE_CURRENT_BINARY_DIR})
add_executable(${BIN_NAME} ${OS_BUNDLE} ${ViConfigTool_SRC} ${META_FILES} ${CONF_FILES} ${PLUGIN_FILEs})
target_include_directories(${BIN_NAME} PUBLIC ${INC_DEPS} ${ViConfigToolDir} )
# target_link_directories(${BIN_NAME} PUBLIC ${INC_LIB})
target_link_libraries(${BIN_NAME} PUBLIC ${LIB_FMWKs} ${LIB_DEPS}
        ${OPENGL_gl_LIBRARY} # https://cmake.org/cmake/help/v3.0/module/FindOpenGL.html
        )

# add app res
# APP_ADD_RES("${PROJ_ROOT}/conf/project.json" "Resources/")
APP_ADD_RES_RECURSE("${CONF_DIR}/" "conf/" "${CONF_DIR}/*.*")
APP_ADD_RES_RECURSE("${TOOLS_DIR}/" "tools/" "${TOOLS_DIR}/*.*")

if(WITH_QT) 
    QT_DEPLOY(${BIN_NAME}) # From qt_func.cmake. Deploy Qt Libs To APP 
    target_compile_definitions(${BIN_NAME} PRIVATE
                                $<$<OR:$<CONFIG:Debug>,$<CONFIG:RelWithDebInfo>>:QT_QML_DEBUG>
                                $<$<OR:$<CONFIG:Release>,$<CONFIG:MinSizeRel>>:QT_NO_DEBUG_OUTPUT>)
endif(WITH_QT)

# install libs & headers
INSTALL_INC(${CMAKE_CURRENT_LIST_DIR} include/)
# INSTALL_TARGET(${BIN_NAME}) # lib bin exe
if(WIN)
    WIN_FIX_COMPILER(${BIN_NAME})
    # INSTALL_TARGET(${BIN_NAME}) # lib bin exe
elseif(APPLE)
    # from intern cmake module : apple_func.cmake
    XCODE_SETTING(${BIN_NAME} ${OS_MIN_VERSION})
    XCODE_ADD_INFO_PLIST(${BIN_NAME})
endif(APPLE)

if(QLandscapeDB)
    add_dependencies(${BIN_NAME} QLandscapeDB)
else()
    message(FATAL_ERROR "option ON for QLandscapeDB is required !")
endif(QLandscapeDB)

if(QtCoreKit)
    add_dependencies(${BIN_NAME} QtCoreKit)
else()
    message(FATAL_ERROR "option ON for QtCoreKit is required !")
endif(QtCoreKit)

if(CCoreKit)
    add_dependencies(${BIN_NAME} CCoreKit)
else()
    message(FATAL_ERROR "option ON for CCoreKit is required !")
endif(CCoreKit)
