# MIT License
# 
# Copyright (c) 2021~2022 [coder4869](https://github.com/coder4869)
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

set(QLandscapeDBDir ${CMAKE_CURRENT_LIST_DIR})
set(LIB_NAME QLandscapeDB)

FILE(GLOB_RECURSE QLandscapeDB_SRC
    ${QLandscapeDBDir}/*.h
    ${QLandscapeDBDir}/*.hpp

    ${QLandscapeDBDir}/*.c
    ${QLandscapeDBDir}/*.cc
    ${QLandscapeDBDir}/*.cpp
    )

FILE(GLOB_RECURSE QLandscapeDB_FORMs 
    ${QLandscapeDBDir}/Forms/*.ui
    )

FILE(GLOB_RECURSE QLandscapeDB_RES
    ${QLandscapeDBDir}/Res/*.qrc
    ${QLandscapeDBDir}/Res/*.qml
    ${QLandscapeDBDir}/Res/*.js
    )

if(NOT ANDROID)
    source_group(
        TREE ${QLandscapeDBDir}
        PREFIX "QLandscapeDB"
        FILES ${QLandscapeDB_SRC} ${QLandscapeDB_FORMs} ${QLandscapeDB_RES}
        )
endif(NOT ANDROID)

# gen src by forms
qt5_wrap_ui(QLandscapeDB_RES_UIC ${QLandscapeDB_FORMs})
INCLUDE_DIRECTORIES(${CMAKE_CURRENT_BINARY_DIR})

# update QLandscapeDB_SRC
set(QLandscapeDB_SRC ${QLandscapeDB_SRC} ${QLandscapeDB_FORMs} ${QLandscapeDB_RES} ${QLandscapeDB_RES_UIC})

set(LIB_DEPS QtCoreKit CCoreKit )

add_library(${LIB_NAME} ${LIB_TYPE} ${QLandscapeDB_SRC})
target_include_directories(${LIB_NAME} PRIVATE ${INC_QT} ${INC_PY} ${QLandscapeDBDir} ${INC_GROUP} )
target_link_libraries(${LIB_NAME} ${LIB_QT} ${LIB_PY} ${LIB_DEPS})

# install libs & headers
INSTALL_INC(${CMAKE_CURRENT_LIST_DIR} include/)
INSTALL_TARGET(${LIB_NAME}) # lib bin exe

# from intern cmake module : apple_func.cmake
if(APPLE)
    XCODE_SETTING(${LIB_NAME} ${OS_MIN_VERSION})
endif(APPLE)

if(QtCoreKit)
    add_dependencies(${LIB_NAME} QtCoreKit)
else()
    message(FATAL_ERROR "option ON for QtCoreKit is required !")
endif(QtCoreKit)

if(CCoreKit)
    add_dependencies(${LIB_NAME} CCoreKit)
else()
    message(FATAL_ERROR "option ON for CCoreKit is required !")
endif(CCoreKit)
